Hamiltonian Class
=================

This is the main Hamiltonian class that combines everything together to make
a complete Hamiltonian.

Overview
--------

.. currentmodule:: pylcp

.. autosummary::

    hamiltonian


Detailed functions
------------------

.. autoclass:: pylcp.hamiltonian
  :members:
